
local cjson = require "cjson"

local filePath = "/home/shenzhiming/nginx/logs/wx_tracker/event.log"
local json = cjson.new()

-- table 合并函数
local function merge(target, src)
	for k, v in pairs(src) do
		target[k] = v
	end
end

-- 获取客户端真实ip
local function get_client_ip()
	local headers = ngx.req.get_headers()
	local ip = headers["X-REAL-IP"] or headers["X_FORWARDED_FOR"] or ngx.var.remote_addr or "0.0.0.0"
	return ip
end

-- 获取基础的请求头信息
local function reqHeaders()
	local headers = {}
	headers["log_ts"] = ngx.var.msec * 1000
	headers["ip"] = get_client_ip()
	headers["status"] = "200"
	headers["ua"] = ngx.var.http_user_agent or "-"
	headers["http_referer"] = ngx.var.http_referer or "-"
	return headers
end

-- event 事件字段映射
local function keyMap(headers)
	local request_method = ngx.var.request_method
	local args = {}
	if "GET" == request_method then
		args = ngx.decode_args(ngx.var.args)
	elseif "POST" == request_method then
		ngx.req.read_body()
		local receive_headers = ngx.req.get_headers()
		if receive_headers["content-type"] == "application/json" then
			local json_args = ngx.req.get_body_data()
			if json_args then
				args = cjson.decode(json_args)
			end
		else
			args = ngx.req.get_post_args()
		end
	end
	headers["id"] = args["g_id"] or 0
	headers["ts"] = args["g_ts"] or 0
	headers["uid"] = args["g_uid"] or ""
	headers["sdk_version"] = args["g_sv"] or ""
	headers["app_key"] = args["g_ak"] or ""
	headers["path"] = args["g_p"] or ""
	headers["query"] = args["g_q"] or ""
	headers["chn"] = args["g_q_chn"] or ""
	headers["parent_id"] = args["g_q_id"] or 0
	headers["scene"] = args["g_se"] or 0
	headers["share_ticket"] = args["g_st"] or ""
	headers["referrer_appid"] = args["g_r_id"] or ""
	headers["event_id"] = args["u_ei"] or 0
	headers["event_key"] = args["u_ek"] or ""
	headers["event_params"] = args["u_par"] or ""
	headers["stay_time"] = args["g_stt"] or 0
	headers["share_from"] = args["g_sf"] or ""
	headers["brand"] = args["s_b"] or ""
	headers["model"] = args["s_m"] or ""
	headers["pixel_ratio"] = args["s_p"] or 0
	headers["width"] = args["s_w"] or 0
	headers["height"] = args["s_h"] or 0
	headers["language"] = args["s_l"] or ""
	headers["wx_version"] = args["s_v"] or ""
	headers["platform"] = args["s_pl"] or ""
	headers["wx_sdk_version"] = args["s_sv"] or ""
	headers["system"] = args["s_sy"] or ""
	headers["net_type"] = args["s_nt"] or ""
	headers["latitude"] = args["s_lat"] or 0
	headers["longitude"] = args["s_lng"] or 0
	headers["speed"] = args["s_spd"] or 0
	return json.encode(headers).."\n"
end

-- 将获取的 json 串写入文件
local function writeLog(content)
	local file = io.open(filePath, "a")
	io.output(file)
	io.write(content)
	io.close(file)
end

-- 处理过程
local content = keyMap(reqHeaders())
writeLog(content)


